*Replication for:
*Hansen, K. M. (2007) The Sophisticated Public: The Effect of Competing Frames on public opinion. Scandinavian Political Studies. 30(3):377-396.

*Stata version v15

*Folder for datafile
cd "H:\Projekter\SSF\Island 2005"
*use "H:\Projekter\SSF\Island 2005\KMH - Split Sample Survey 2005.dta",clear
*keep Response_rate s_22 s_23 s_24 s_25 s_27 s27* s_28 s28* s_29 s_31 s_32 s_37 s_38 s_39 s_40 split*
*compress
*save sps_replication_table2.dta,replace

use "sps_replication_table2.dta",clear

*Keep only fully completed interviews
keep if Response_rate == 1


*******************************.
*Tabel 2. SPS-article
*******************************.

*1. row in table 2
recode s_29 (1=100)(3=-100) (2=0) (4=0), gen(s_29_index)
lab var s_29_index "Do you think that the public spends too much money (100), adequately (0) or too little money (-100) on public schools?"
lab var split8 "Frame"
label define SPLIT8 2 "Danish students are criticized in international studies for poor reading skills" 1 "Denmark is among the countries spending the most money per student" 3 "Dual frame" 4 "Control frame", replace
recode split8 (1=2) (2=1)
tabout split8 using temp.xls, replace c(mean s_29_index sd s_29_index N s_29_index) f(0 2 0) npos(col) clab("Do_you_think_that_the_public_spends_too_much_money_(100),_adequately_(0)_or_too_little_money_(-100)_on_public_schools?") sum
ttest s_29_index if split8==1 | split8==4, by(split8)
ttest s_29_index if split8==2 | split8==4, by(split8)
ttest s_29_index if split8==3 | split8==4, by(split8)

*2. row in table 2
recode s_31 (1=100) (2=50) (3=0) (4=-50) (5=-100) (6=0), gen(s_31_index) 
lab var s_31_index "To what extent do you agree to that we ought to increase the competition between the students in the public schools?"
lab var split9 "Frame"
label define SPLIT9 1 "Competition between the students in the public schools stimulates the students to work hard and develop new ideas" 2 "Competition between the students in the public schools brings out the worst in the students and does not create complete people" 3 "Dual frame" 4 "Control frame", replace
tabout split9 using temp.xls, append c(mean s_31_index sd s_31_index N s_31_index) f(0 2 0) npos(col) clab("To_what_extent_do_you_agree_to_that_we_ought_to_increase_the_competition_between_the_students_in_the_public_schools?") sum
ttest s_31_index if split9==1 | split9==4, by(split9)
ttest s_31_index if split9==2 | split9==4, by(split9)
ttest s_31_index if split9==3 | split9==4, by(split9)

*3. row in table 2
recode s_32 (1=100)(3=-100) (2=0) (4=0), gen(s_32_index) 
lab var s_32_index "Do you think that the public spends too much money (100), adequately (0) or too little money (-100) on public transfer income?"
lab var split10 "Frame"
label define SPLIT10 1 "One of the largest public expenditures is public transfer income" 2 "Public transfer income creates a security net for the individual citizen" 3 "Dual frame" 4 "Control frame", replace
tabout split10 using temp.xls, append c(mean s_32_index sd s_32_index N s_32_index) f(0 2 0) npos(col) clab ("Do_you_think_that_the_public_spends_too_much_money_(100),_adequately_(0)_or_too_little_money_(-100)_on_public_transfer_income?") sum
ttest s_32_index if split10==1 | split10==4, by(split10)
ttest s_32_index if split10==2 | split10==4, by(split10)
ttest s_32_index if split10==3 | split10==4, by(split10)

*4. row in table 2
recode s_37 (1=100) (2=50) (3=0) (4=-50) (5=-100) (6=0), gen(s_37_index) 
lab var s_37_index "To what extent do you agree that a good way to increase employment would be to lower unemployment benefits?"
lab var split12 "Frame"
label define SPLIT12 1 "If unemployed persons do not take the worked offered to them, they ought to lose their unemployment benefits" 2 "Unemployment is seldom self-induced" 3 "Dual frame" 4 "Control frame", replace
tabout split12 using temp.xls, append c(mean s_37_index sd s_37_index N s_37_index) f(0 2 0) npos(col) clab("To_what_extent_do_you_agree_that_a_good_way_to_increase_employment_would_be_to_lower_unemployment_benefits?") sum
ttest s_37_index if split12==1 | split12==4, by(split12)
ttest s_37_index if split12==2 | split12==4, by(split12)
ttest s_37_index if split12==3 | split12==4, by(split12)

*5. row in table 2
recode s_38 (1=100) (2=50) (3=0) (4=-50) (5=-100) (6=0), gen(s_38_index) 
lab var s_38_index "To what extent do you agree that a good way to increase employment would be to lower taxes on work?"
tabout split12 using temp.xls, append c(mean s_38_index sd s_38_index N s_38_index) f(0 2 0) npos(col) clab("To_what_extent_do_you_agree_that_a_good_way_to_increase_employment_would_be_to_lower_taxes_on_work?") sum
ttest s_38_index if split12==1 | split12==4, by(split12)
ttest s_38_index if split12==2 | split12==4, by(split12)
ttest s_38_index if split12==3 | split12==4, by(split12)

*6. row in table 2
recode s_40 (1=100) (2=0) (3=-100) (4=0), gen(s_40_index) 
lab var s_40_index "If you have to choose between the three ways of increasing employment – lowering unemployment benefits (coded 100), lowering taxes on work (0) or increasing in-service training (-100) – what would you prefer?"
tabout split12 using temp.xls, append c(mean s_40_index sd s_40_index N s_40_index) f(0 2 0) npos(col) clab("If_you_have_to_choose_between_the_three_ways_of_increasing_employment_–_lowering_unemployment_benefits_(coded_100),_lowering_taxes_on_work_(0)_or_increasing_in-service_training_(-100)_–_what_would_you_prefer?") sum
ttest s_40_index if split12==1 | split12==4, by(split12)
ttest s_40_index if split12==2 | split12==4, by(split12)
ttest s_40_index if split12==3 | split12==4, by(split12)

*7. row in table 2
recode s_39 (1=100) (2=50) (3=0) (4=-50) (5=-100) (6=0), gen(s_39_index) 
lab var s_39_index "To what extent do you agree that a good way to increase employment would be to increase in-service training?"
recode split12 (1=2) (2=1)
label define SPLIT12 2 "If unemployed persons do not take the worked offered to them, they ought to lose their unemployment benefits" 1 "Unemployment is seldom self-induced" 3 "Dual frame" 4 "Control frame", replace
tabout split12 using temp.xls, append c(mean s_39_index sd s_39_index N s_39_index) f(0 2 0) npos(col) clab ("To_what_extent_do_you_agree_that_a_good_way_to_increase_employment_would_be_to_increase_in-service_training") sum
ttest s_39_index if split12==1 | split12==4, by(split12)
ttest s_39_index if split12==2 | split12==4, by(split12)
ttest s_39_index if split12==3 | split12==4, by(split12)

*8. row in table 2
recode s_22 (1=-100) (2=-80) (3=-60) (4=-40) (5=-20) (6=0) (7=20) (8=40) (9=60) (10=80) (11=100) (12=0), gen(s_22_index) 
lab var s_22_index "In politics you often hear about left and right. Where would you place your self on a scale, where 0 is the furthest to the left and 10 the furthest to the right (11 points scale. Coded -100 to 100)?"
lab var split2 "Frame"
label define SPLIT2 2 "Left in politics is, among other things, related to the public attempting to ensure that everybody is taken care of" 1 "Right in politics is, among other things, related to the individual person having greater responsibly for himself" 3 "Dual frame" 4 "Control frame", replace
recode split2 (1=2) (2=1)
tabout split2 using temp.xls, append c(mean s_22_index sd s_22_index N s_22_index) f(0 2 0) npos(col) clab("In_politics_you_often_hear_about_left_and_right._Where_would_you_place_your_self_on_a_scale,_where_0_is_the_furthest_to_the_left_and_10_the_furthest_to_the_right_(11_points_scale._Coded_-100_to_100)?") sum
ttest s_22_index if split2==1 | split2==4, by(split2)
ttest s_22_index if split2==2 | split2==4, by(split2)
ttest s_22_index if split2==3 | split2==4, by(split2)

*9. row in table 2
recode s_23 (1=100) (2=-100) (3/5=0), gen(s_23_index) 
lab var s_23_index "Choice between personal liberty (100) or equality between citizens (-100), (either nor, 0)"
lab var split3 "Frame"
label define SPLIT3 1 "Personal liberty ensures that everyone can develop without obstacles" 2 "Equality between citizens ensures everyone the opportunity to get ahead in the world and ensures fewer social cleavages" 3 "Dual frame" 4 "Control frame", replace
tabout split3 using temp.xls, append c(mean s_23_index sd s_23_index N s_23_index) f(0 2 0) npos(col) clab("Choice_between_personal_liberty_(100)_or_equality_between_citizens_(-100),_(either_nor,_0)") sum
ttest s_23_index if split3==1 | split3==4, by(split3)
ttest s_23_index if split3==2 | split3==4, by(split3)
ttest s_23_index if split3==3 | split3==4, by(split3)

*10. row in table 2
recode s_24 (1=100) (2=50) (3=0) (4=-50) (5=-100) (6=0), gen(s_24_index) 
lab var s_24_index "To what extent do you agree that society must seek to equalize large differences in income distribution within the population?"
label define SPLIT4 1 "Income redistribution helps secure that the difference between the rightist and the poorest are equalized" 2 "Denmark is one of the countries with the greatest taxation burden" 3 "Dual frame" 4 "Control frame", replace
lab var split4 "Frame"
recode split4 (1=2) (2=1)
tabout split4 using temp.xls, append c(mean s_24_index sd s_24_index N s_24_index) f(0 2 0) npos(col) clab("To_what_extent_do_you_agree_that_society_must_seek_to_equalize_large_differences_in_income_distribution_within_the_population?") sum
ttest s_24_index if split4==1 | split4==4, by(split4)
ttest s_24_index if split4==2 | split4==4, by(split4)
ttest s_24_index if split4==3 | split4==4, by(split4)

*11. row in table 2
recode s_25 (1=100) (2=50) (3=0) (4=-50) (5=-100) (6=0), gen(s_25_index) 
lab var s_25_index "To what extent do you agree that society must seek to meet everyone’s basic needs for food, housing, clothing, education and healthcare?"
tabout split4 using temp.xls, append c(mean s_25_index sd s_25_index N s_25_index) f(0 2 0) npos(col) clab("To_what_extent_do_you_agree_that_society_must_seek_to_meet_everyone’s_basic_needs_for_food,_housing,_clothing,_education_and_healthcare?") sum
ttest s_25_index if split4==1 | split4==4, by(split4)
ttest s_25_index if split4==2 | split4==4, by(split4)
ttest s_25_index if split4==3 | split4==4, by(split4)

*12. row in table 2
gen forfatning =s_27
replace forfatning=s27_4 if s_27==4
replace forfatning=s27_5 if s_27==5
replace forfatning=s27_6 if s_27==6
recode forfatning (3/7=.)
recode forfatning (1=100) (2=-100) (.=0) (else=0),gen(forfatning_index) 
lab var forfatning_index "What would you vote for if there was a referendum on the European constitution held tomorrow?"
recode split6 (1=2) (2=1)
lab var split6 "Frame"
label define SPLIT6 1 "The European constitution is necessary because of the increased numbers of member states" 2 "The European constitution is a step toward the United States of Europe" 3 "Dual frame" 4 "Control frame", replace
tabout split6 using temp.xls, append c(mean forfatning_index sd forfatning_index  N forfatning_index ) f(0 2 0) npos(col) clab("What_would_you_vote_for_if_there_was_a_referendum_on_the_European_constitution_held_tomorrow?") sum
ttest forfatning if split6==1 | split6==4, by(split6)
ttest forfatning if split6==2 | split6==4, by(split6)
ttest forfatning if split6==3 | split6==4, by(split6)

*13. row in table 2
gen euroen=s_28
replace euroen=s28_4 if s_28==4
replace euroen=s28_5 if s_28==5
replace euroen=s28_6 if s_28==6
recode euroen (3/7=.)
recode euroen (1=100) (2=-100) (.=0) (else=0),gen(euroen_index) 
lab var euroen_index "What would you vote for if there was a referendum on the euro held tomorrow?"
lab var split7 "Frame"
recode split7 (1=2) (2=1) 
label define SPLIT7 1 "If Denmark introduces the euro, we don’t need to exchange money when traveling abroad" 2 "If Denmark introduces the euro, Denmark will lose an important national symbol" 3 "Dual frame" 4 "Control frame", replace
tabout split7 using temp.xls, append c(mean euroen_index sd euroen_index N euroen_index) f(0 2 0) npos(col) clab("What_would_you_vote_for_if_there_was_a_referendum_on_the_euro_held_tomorrow?") sum
ttest euroen_index if split7==1 | split7==4, by(split7)
ttest euroen_index if split7==2 | split7==4, by(split7)
ttest euroen_index if split7==3 | split7==4, by(split7)

unicode convertfile "temp.xls" "SPS_table2.xls", dstencoding(Windows-1252) replace
